@@ -34,6 +34,8 @@
 
 #include <gio/gio.h>
 
+#include <gtk/gtk.h>
+
 #ifdef BUILD_PLAYLIST
 #include <totem-pl-parser.h>
 #endif
@@ -42,6 +44,7 @@
 #include "burn-debug.h"
 #include "burn-volume.h"
 
+#include "brasero-app.h"
 #include "brasero-utils.h"
 #include "brasero-io.h"
 #include "brasero-metadata.h"
@@ -303,13 +306,17 @@ brasero_io_return_result_idle (gpointer callback_data)
 
 	priv = BRASERO_IO_PRIVATE (self);
 
+	g_mutex_lock (priv->lock);
+	priv->results_id = 0;
+	if (!priv->results) {
+		g_mutex_unlock (priv->lock);
+		return FALSE;
+	}
+
 	/* Return several results at a time that can be a huge speed gain.
 	 * What should be the value that provides speed and responsiveness. */
 	for (i = 0; i < 25; i ++) {
-		g_mutex_lock (priv->lock);
-
 		if (!priv->results) {
-			priv->results_id = 0;
 			g_mutex_unlock (priv->lock);
 			return FALSE;
 		}
@@ -333,9 +340,12 @@ brasero_io_return_result_idle (gpointer callback_data)
 						       result->base->destroy,
 						       FALSE);
 		brasero_io_job_result_free (result);
+		g_mutex_lock (priv->lock);
 	}
 
-	return TRUE;
+	g_mutex_unlock (priv->lock);
+
+	return FALSE;
 }
 
 static void
@@ -516,18 +526,6 @@ brasero_io_mount_enclosing_volume_cb (GObject *source,
 	mount->finished = TRUE;
 }
 
-static void
-brasero_io_mount_ask_password (GMountOperation *operation,
-			       gchar *message,
-			       gchar *default_user,
-			       gchar *default_domain,
-			       GAskPasswordFlags flags,
-			       gpointer user_data)
-{
-	BRASERO_BURN_LOG ("Password asked");
-	g_mount_operation_reply (operation, G_MOUNT_OPERATION_HANDLED);
-}
-
 static gboolean
 brasero_io_mount_enclosing_volume (BraseroIO *self,
 				   GFile *file,
@@ -538,13 +536,7 @@ brasero_io_mount_enclosing_volume (BraseroIO *self,
 	GMountOperation *operation;
 	BraseroIOMount mount = { NULL, };
 
-	operation = g_mount_operation_new ();
-	g_mount_operation_set_anonymous (operation, TRUE);
-	g_signal_connect (operation,
-			  "ask-password",
-			  G_CALLBACK (brasero_io_mount_ask_password),
-			  NULL);
-
+	operation = gtk_mount_operation_new (GTK_WINDOW (brasero_app_get_default ()));
 	g_file_mount_enclosing_volume (file,
 				       G_MOUNT_MOUNT_NONE,
 				       operation,
@@ -1044,7 +1036,7 @@ brasero_io_get_file_info_thread_real (BraseroAsyncTaskManager *manager,
 
 	info = g_file_query_info (file,
 				  attributes,
-				  G_FILE_QUERY_INFO_NONE,	/* follow symlinks */
+				  (options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 				  cancel,
 				  &local_error);
 	if (!info) {
@@ -1504,8 +1496,7 @@ brasero_io_get_file_count_process_playlist (BraseroIO *self,
 						       child_uri,
 						       info,
 						       ((data->job.options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0) |
-						       BRASERO_METADATA_FLAG_FAST,
+						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0),
 						       &metadata);
 
 		if (result)
@@ -1600,7 +1591,7 @@ brasero_io_get_file_count_process_directory (BraseroIO *self,
 
 	enumerator = g_file_enumerate_children (file,
 						attributes,
-						G_FILE_QUERY_INFO_NONE,	/* follow symlinks */
+						(data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 						cancel,
 						NULL);
 	if (!enumerator) {
@@ -1665,7 +1656,7 @@ brasero_io_get_file_count_start (BraseroIO *self,
 	file = g_file_new_for_uri (uri);
 	info = g_file_query_info (file,
 				  attributes,
-				  G_FILE_QUERY_INFO_NONE, /* follow symlinks */
+				  (data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 				  cancel,
 				  NULL);
 
@@ -1850,8 +1841,7 @@ brasero_io_load_directory_playlist (BraseroIO *self,
 						       child_uri,
 						       info,
 						       ((data->job.options & BRASERO_IO_INFO_METADATA_MISSING_CODEC) ? BRASERO_METADATA_FLAG_MISSING : 0) |
-						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0) |
-						       BRASERO_METADATA_FLAG_FAST,
+						       ((data->job.options & BRASERO_IO_INFO_METADATA_THUMBNAIL) ? BRASERO_METADATA_FLAG_THUMBNAIL : 0),
 						       &metadata);
 
 		if (result) {
@@ -1914,7 +1904,7 @@ brasero_io_load_directory_thread (BraseroAsyncTaskManager *manager,
 
 	enumerator = g_file_enumerate_children (file,
 						attributes,
-						G_FILE_QUERY_INFO_NONE,		/* follow symlinks */
+						(data->job.options & BRASERO_IO_INFO_FOLLOW_SYMLINK)?G_FILE_QUERY_INFO_NONE:G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,	/* follow symlinks by default*/
 						cancel,
 						&error);
 
@@ -2325,7 +2315,7 @@ brasero_io_xfer_recursive_thread (BraseroIOXferData *data,
 	enumerator = g_file_enumerate_children (src,
 						G_FILE_ATTRIBUTE_STANDARD_TYPE ","
 						G_FILE_ATTRIBUTE_STANDARD_NAME,
-						G_FILE_QUERY_INFO_NONE,	/* follow symlinks */
+						G_FILE_QUERY_INFO_NONE,	/* follow symlinks by default */
 						cancel,
 						error);
 	if (!enumerator)
@@ -2397,7 +2387,7 @@ brasero_io_xfer_start (BraseroIO *self,
 	data->info = g_file_query_info (file,
 					G_FILE_ATTRIBUTE_STANDARD_TYPE","
 					G_FILE_ATTRIBUTE_STANDARD_SIZE,
-					G_FILE_QUERY_INFO_NONE, /* follow symlinks */
+					G_FILE_QUERY_INFO_NONE,	/* follow symlinks by default*/
 					cancel,
 					error);
 	if (!data->info || error) {
