@@ -601,8 +601,8 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 					   GError *error,
 					   BraseroSplitDialog *self)
 {
+	BraseroMetadataInfo info = { NULL, };
 	BraseroSplitDialogPrivate *priv;
-	BraseroMetadataInfo info;
 	gboolean added_silence;
 	GSList *iter;
 
@@ -634,6 +634,9 @@ brasero_split_dialog_metadata_finished_cb (BraseroMetadata *metadata,
 
 		silence = iter->data;
 
+		if (!silence)
+			continue;
+
 		if (silence->start >= priv->end)
 			continue;
 
@@ -773,7 +776,9 @@ brasero_split_dialog_cut_clicked_cb (GtkButton *button,
 			return;
 
 		gtk_list_store_clear (priv->model);
-		for (start = step; start < length; start += step)
+
+		parts --;
+		for (start = step; start < length && parts; start += step, parts --)
 			brasero_split_dialog_cut (self, start, FALSE);
 
 		return;
@@ -1292,6 +1297,7 @@ brasero_split_dialog_init (BraseroSplitDialog *object)
 	g_free (title);
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (priv->combo), 0);
+	g_object_unref (size_group);
 }
 
 static void
