@@ -43,9 +43,9 @@
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "burn-track.h"
-#include "burn-medium.h"
-#include "burn-drive.h"
-#include "burn-medium-monitor.h"
+#include "brasero-medium.h"
+#include "brasero-drive.h"
+#include "brasero-medium-monitor.h"
 
 G_DEFINE_TYPE (BraseroBurnSession, brasero_burn_session, G_TYPE_OBJECT);
 #define BRASERO_BURN_SESSION_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_BURN_SESSION, BraseroBurnSessionPrivate))
@@ -327,14 +327,19 @@ brasero_burn_session_set_input_type (BraseroBurnSession *self,
 				     BraseroTrackType *type)
 {
 	BraseroBurnSessionPrivate *priv;
+	BraseroTrackType input = { 0, };
 
 	g_return_if_fail (BRASERO_IS_BURN_SESSION (self));
 	g_return_if_fail (type != NULL);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
+	brasero_burn_session_get_input_type (self, &input);
 	memcpy (&priv->input, type, sizeof (BraseroTrackType));
 
+	if (brasero_track_type_equal (&input, type))
+		return;
+
 	if (!priv->tracks)
 		g_signal_emit (self,
 			       brasero_burn_session_signals [INPUT_CHANGED_SIGNAL],
@@ -771,8 +776,9 @@ brasero_burn_session_get_tmp_file (BraseroBurnSession *self,
 	if (fd == -1) {
                 int errsv = errno;
 
+		BRASERO_BURN_LOG ("Impossible to create tmp file %s", tmp);
+
 		g_free (tmp);
-		BRASERO_BURN_LOG ("Impossible to create tmp file");
 		if (errsv != EACCES)
 			g_set_error (error, 
 				     BRASERO_BURN_ERROR,
@@ -1538,6 +1544,8 @@ brasero_burn_session_finalize (GObject *object)
 	BraseroBurnSessionPrivate *priv;
 	GSList *iter;
 
+	BRASERO_BURN_LOG ("Cleaning session");
+
 	priv = BRASERO_BURN_SESSION_PRIVATE (object);
 
 	if (priv->tags) {
