@@ -783,6 +783,7 @@ brasero_track_get_data_excluded_source (BraseroTrack *track,
 
 BraseroBurnResult
 brasero_track_get_data_paths (BraseroTrack *track,
+			      gboolean use_joliet,
 			      const gchar *grafts_path,
 			      const gchar *excluded_path,
 			      const gchar *emptydir,
@@ -798,6 +799,7 @@ brasero_track_get_data_paths (BraseroTrack *track,
 	data = (BraseroTrackData *) track;
 	result = brasero_mkisofs_base_write_to_files (data->grafts,
 						      data->excluded,
+						      use_joliet,
 						      emptydir,
 						      videodir,
 						      grafts_path,
@@ -1028,6 +1030,7 @@ brasero_track_get_image_size (BraseroTrack *track,
 			return BRASERO_BURN_ERR;
 
 		path = brasero_track_get_localpath (image->image);
+
 		if (!brasero_image_format_get_iso_size (path, blocks, size, error)) {
 			g_free (path);
 			return BRASERO_BURN_ERR;
@@ -1041,6 +1044,7 @@ brasero_track_get_image_size (BraseroTrack *track,
 		gchar *path;
 
 		path = brasero_track_get_image_source (track, FALSE);
+
 		if (!path)
 			return BRASERO_BURN_ERR;
 
